import webpack from 'webpack';
import path from 'path';
import WebpackNotifierPlugin from 'webpack-notifier';
import MiniCssExtractPlugin from 'mini-css-extract-plugin';

const config = process.env.NODE_ENV === 'test'
  ? require('./webpack.config.test').default
  : require('./webpack.config').default;

const postcss = [
  require('css-mqpacker')({
    sort: true
  }),
  require('autoprefixer')
];

const scss = {
  test: /\.scss$/,
  use: [
    MiniCssExtractPlugin.loader,
    {
      loader: "css-loader",
      options: {
        minimize: {
          safe: true
        }
      }
    },
    {
      loader: "postcss-loader",
      options: {}
    },
    {
      loader: "sass-loader",
      options: {}
    }
  ]
};

const buildRules = [...config.module.rules, scss];
const buildPlugins = [...config.plugins, new MiniCssExtractPlugin(config.bundleCSS)];

export default {
  entry: config.entry,
  output: config.output,
  optimization: {
    splitChunks: {
      minChunks: 3
    }
  },
  mode: "production",
  module: {
    rules: buildRules,
  },
  plugins: buildPlugins
};

